@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "7.4"
-#define S7_DATE "24-Sep-18"
+#define S7_VERSION "8.0"
+#define S7_DATE "2-Jan-19"
 
 #include <stdint.h>           /* for int64_t */
 
@@ -117,24 +117,24 @@ s7_pointer s7_wrong_number_of_args_error(s7_scheme *sc, const char *caller, s7_p
 s7_pointer s7_stacktrace(s7_scheme *sc);
 s7_pointer s7_history(s7_scheme *sc);                                /* the current (circular backwards) history buffer */
 s7_pointer s7_add_to_history(s7_scheme *sc, s7_pointer entry);       /* add entry to the history buffer */
-
-s7_int s7_gc_protect(s7_scheme *sc, s7_pointer x);
-void s7_gc_unprotect(s7_scheme *sc, s7_pointer x);
-void s7_gc_unprotect_at(s7_scheme *sc, s7_int loc);
-s7_pointer s7_gc_protected_at(s7_scheme *sc, s7_int loc);
-s7_pointer s7_gc_protect_via_stack(s7_scheme *sc, s7_pointer x);
+bool s7_history_enabled(s7_scheme *sc);
+bool s7_set_history_enabled(s7_scheme *sc, bool enabled);
 
 s7_pointer s7_gc_on(s7_scheme *sc, bool on);                         /* (gc on) */
 void s7_gc_stats(s7_scheme *sc, bool on);                            /* (*s7* 'gc-stats) */
 
+s7_int s7_gc_protect(s7_scheme *sc, s7_pointer x);
+void s7_gc_unprotect_at(s7_scheme *sc, s7_int loc);
+s7_pointer s7_gc_protected_at(s7_scheme *sc, s7_int loc);
+s7_pointer s7_gc_protect_via_stack(s7_scheme *sc, s7_pointer x);
+
   /* any s7_pointer object held in C (as a local variable for example) needs to be
    *   protected from garbage collection if there is any chance the GC may run without
    *   an existing Scheme-level reference to that object.  s7_gc_protect places the
    *   object in a vector that the GC always checks, returning the object's location
-   *   in that table.  s7_gc_unprotect and s7_gc_unprotect_at unprotect the object
-   *   (remove it from the vector).  s7_gc_unprotect_at uses the location passed
-   *   to it, whereas s7_gc_unprotect scans the vector to find the object.  
-   *   s7_gc_protected_at returns the object at the given location.
+   *   in that table.  s7_gc_unprotect_at unprotects the object (removes it from the
+   *   vector) using the location passed to it.  s7_gc_protected_at returns the object 
+   *   at the given location.
    * 
    * You can turn the GC on and off via s7_gc_on.
    *
@@ -143,11 +143,9 @@ void s7_gc_stats(s7_scheme *sc, bool on);                            /* (*s7* 'g
    *    very short term temps such as the arguments to s7_cons in:
    *
    *    s7_cons(s7, s7_make_real(s7, 3.14), 
-   *                s7_cons(s7, s7_make_integer(s7, 123), 
-   *                            s7_nil(s7)));
+   *                s7_cons(s7, s7_make_integer(s7, 123), s7_nil(s7)));
    */
 
-
 bool s7_is_eq(s7_pointer a, s7_pointer b);                                   /* (eq? a b) */
 bool s7_is_eqv(s7_pointer a, s7_pointer b);                                  /* (eqv? a b) */
 bool s7_is_equal(s7_scheme *sc, s7_pointer a, s7_pointer b);                 /* (equal? a b) */
@@ -368,11 +366,6 @@ bool s7_is_keyword(s7_pointer obj);                                         /* (
 s7_pointer s7_make_keyword(s7_scheme *sc, const char *key);                 /* (string->keyword key) */
 s7_pointer s7_keyword_to_symbol(s7_scheme *sc, s7_pointer key);             /* (keyword->symbol key) */
 
-s7_pointer s7_slot(s7_scheme *sc, s7_pointer symbol);
-s7_pointer s7_slot_value(s7_pointer slot);
-s7_pointer s7_slot_set_value(s7_scheme *sc, s7_pointer slot, s7_pointer value);
-s7_pointer s7_make_slot(s7_scheme *sc, s7_pointer env, s7_pointer symbol, s7_pointer value);
-
 s7_pointer s7_rootlet(s7_scheme *sc);                                       /* (rootlet) */
 s7_pointer s7_shadow_rootlet(s7_scheme *sc);
 s7_pointer s7_set_shadow_rootlet(s7_scheme *sc, s7_pointer let);
@@ -396,7 +389,7 @@ s7_pointer s7_symbol_value(s7_scheme *sc, s7_pointer sym);
 s7_pointer s7_symbol_set_value(s7_scheme *sc, s7_pointer sym, s7_pointer val);
 s7_pointer s7_symbol_local_value(s7_scheme *sc, s7_pointer sym, s7_pointer local_env);
 bool s7_for_each_symbol_name(s7_scheme *sc, bool (*symbol_func)(const char *symbol_name, void *data), void *data);
-bool s7_for_each_symbol(s7_scheme *sc, bool (*symbol_func)(const char *symbol_name, s7_pointer value, void *data), void *data);
+bool s7_for_each_symbol(s7_scheme *sc, bool (*symbol_func)(const char *symbol_name, void *data), void *data);
   
   /* these access the current environment and symbol table, providing
    *   a symbol's current binding (s7_name_to_value takes the symbol name as a char*,
@@ -405,12 +398,10 @@ bool s7_for_each_symbol(s7_scheme *sc, bool (*symbol_func)(const char *symbol_na
    *   as its third argument).
    *
    * To iterate over the complete symbol table, use s7_for_each_symbol_name,
-   *   and s7_for_each_symbol.  The latter calls the 'symbol_func' on each
-   *   symbol, passing the symbol name, its current binding, and the uninterpreted
-   *   'data' pointer.  s7_for_each_symbol_name is similar, but does not include
-   *   the current binding.
-   *
-   * The for-each loop stops if the symbol_func returns true, or at the end of the table.
+   *   and s7_for_each_symbol.  Both call 'symbol_func' on each symbol, passing it
+   *   the symbol or symbol name, and the uninterpreted 'data' pointer.
+   *   the current binding. The for-each loop stops if the symbol_func returns true, 
+   *   or at the end of the table.
    */
 
 s7_pointer s7_dynamic_wind(s7_scheme *sc, s7_pointer init, s7_pointer body, s7_pointer finish);
@@ -608,7 +599,8 @@ void s7_c_type_set_fill     (s7_scheme *sc, s7_int tag, s7_pointer (*fill)     (
 void s7_c_type_set_reverse  (s7_scheme *sc, s7_int tag, s7_pointer (*reverse)  (s7_scheme *sc, s7_pointer args));
 void s7_c_type_set_to_list  (s7_scheme *sc, s7_int tag, s7_pointer (*to_list)  (s7_scheme *sc, s7_pointer args));
 void s7_c_type_set_to_string(s7_scheme *sc, s7_int tag, s7_pointer (*to_string)(s7_scheme *sc, s7_pointer args));
-
+void s7_c_type_set_getter   (s7_scheme *sc, s7_int tag, s7_pointer getter);
+void s7_c_type_set_setter   (s7_scheme *sc, s7_int tag, s7_pointer setter);
 /* if a c-object might participate in a cyclic structure, and you want to check its equality to another such object
  *   or get a readable string representing that object, you need to implement the "to_list" and "set" cases above,
  *   and make the type name a function that can recreate the object.  See the <cycle> object in s7test.scm.
@@ -707,6 +699,10 @@ typedef s7_double (*s7_d_pd_t)(s7_pointer v, s7_double x);
 void s7_set_d_pd_function(s7_pointer f, s7_d_pd_t df);
 s7_d_pd_t s7_d_pd_function(s7_pointer f);
 
+typedef s7_double (*s7_d_7pi_t)(s7_scheme *sc, s7_pointer v, s7_int i);
+void s7_set_d_7pi_function(s7_pointer f, s7_d_7pi_t df);
+s7_d_7pi_t s7_d_7pi_function(s7_pointer f);
+
 typedef s7_double (*s7_d_7pid_t)(s7_scheme *sc, s7_pointer v, s7_int i, s7_double d);
 void s7_set_d_7pid_function(s7_pointer f, s7_d_7pid_t df);
 s7_d_7pid_t s7_d_7pid_function(s7_pointer f);
@@ -715,6 +711,10 @@ typedef s7_double (*s7_d_id_t)(s7_int i, s7_double d);
 void s7_set_d_id_function(s7_pointer f, s7_d_id_t df);
 s7_d_id_t s7_d_id_function(s7_pointer f);
 
+typedef s7_double (*s7_d_ip_t)(s7_int i, s7_pointer p);
+void s7_set_d_ip_function(s7_pointer f, s7_d_ip_t df);
+s7_d_ip_t s7_d_ip_function(s7_pointer f);
+
 typedef s7_int (*s7_i_i_t)(s7_int x);
 void s7_set_i_i_function(s7_pointer f, s7_i_i_t df);
 s7_i_i_t s7_i_i_function(s7_pointer f);
@@ -727,10 +727,6 @@ typedef s7_int (*s7_i_ii_t)(s7_int i1, s7_int i2);
 void s7_set_i_ii_function(s7_pointer f, s7_i_ii_t df);
 s7_i_ii_t s7_i_ii_function(s7_pointer f);
 
-typedef s7_double (*s7_d_ip_t)(s7_int i, s7_pointer p);
-void s7_set_d_ip_function(s7_pointer f, s7_d_ip_t df);
-s7_d_ip_t s7_d_ip_function(s7_pointer f);
-
 typedef s7_int (*s7_i_7p_t)(s7_scheme *sc, s7_pointer p);
 void s7_set_i_7p_function(s7_pointer f, s7_i_7p_t df);
 s7_i_7p_t s7_i_7p_function(s7_pointer f);
@@ -739,10 +735,6 @@ typedef bool (*s7_b_p_t)(s7_pointer p);
 void s7_set_b_p_function(s7_pointer f, s7_b_p_t df);
 s7_b_p_t s7_b_p_function(s7_pointer f);
 
-typedef s7_double (*s7_d_7pi_t)(s7_scheme *sc, s7_pointer v, s7_int i);
-void s7_set_d_7pi_function(s7_pointer f, s7_d_7pi_t df);
-s7_d_7pi_t s7_d_7pi_function(s7_pointer f);
-
 /* Here is an example of using these functions; more extensive examples are in clm2xen.c in sndlib, and in s7.c.
  * (This example comes from a HackerNews discussion):
  * plus.c:
@@ -768,11 +760,16 @@ s7_d_7pi_t s7_d_7pi_function(s7_pointer f);
 
 /* -------------------------------------------------------------------------------- */
 
-
+/* maybe remove these? */
+s7_pointer s7_slot(s7_scheme *sc, s7_pointer symbol);
+s7_pointer s7_slot_value(s7_pointer slot);
+s7_pointer s7_slot_set_value(s7_scheme *sc, s7_pointer slot, s7_pointer value);
+s7_pointer s7_make_slot(s7_scheme *sc, s7_pointer env, s7_pointer symbol, s7_pointer value);
 void s7_slot_set_real_value(s7_scheme *sc, s7_pointer slot, s7_double value);
 
+/* -------------------------------------------------------------------------------- */
 
-  /* this is experimental */
+  /* these will be deprecated and removed eventually */
 s7_pointer s7_apply_1(s7_scheme *sc, s7_pointer args, s7_pointer (*f1)(s7_pointer a1));
 s7_pointer s7_apply_2(s7_scheme *sc, s7_pointer args, s7_pointer (*f2)(s7_pointer a1, s7_pointer a2));
 s7_pointer s7_apply_3(s7_scheme *sc, s7_pointer args, s7_pointer (*f3)(s7_pointer a1, s7_pointer a2, s7_pointer a3));
@@ -839,14 +836,11 @@ typedef s7_double s7_Double;
 #define s7_object_value               s7_c_object_value
 #define s7_make_object                s7_make_c_object
 #define s7_mark_object                s7_mark
-#define s7_procedure_setter           s7_setter
-#define s7_symbol_documentation       s7_documentation
-#define s7_symbol_set_documentation   s7_set_documentation
-#define s7_symbol_setter              s7_setter
-#define s7_symbol_set_setter          s7_set_setter
 #define s7_UNSPECIFIED(Sc)            s7_unspecified(Sc)
 #define s7_NIL(Sc)                    s7_nil(Sc)
 #define s7_new_type(Name, Print, GC_Free, Equal, Mark, Ref, Set) s7_new_type_1(s7, Name, Print, GC_Free, Equal, Mark, Ref, Set)
+
+void s7_gc_unprotect(s7_scheme *sc, s7_pointer x); /* used in CM */
 #endif
 
 
@@ -854,6 +848,12 @@ typedef s7_double s7_Double;
  * 
  *        s7 changes
  *
+ * --------
+ * 29-Dec:    s7_c_type_set_getter|setter (implicit c-object access).
+ * 23-Dec:    remove hash-table, rename hash-table* to hash-table. add weak-hash-table.
+ * 3-Dec:     deprecate s7_gc_unprotect (use s7_gc_unprotect_at).
+ * 21-Nov:    added s7_history_enabled and s7_set_history_enabled.
+ * 3-Nov:     removed the "value" argument from s7_for_each_symbol.
  * 22-Sep:    s7_list_nl.
  * 12-Sep:    byte-vectors can be multidimensional; homogenous vectors of any built-in type. typed hash-tables.
  * 29-Jul:    symbol-setter deprecated (use setter). s7_symbol_documentation (and setter) folded into s7_documentation.
