@@ -55,11 +55,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "9-Oct-18"
+#define SND_DATE "2-Jan-19"
 #ifndef SND_VERSION
-#define SND_VERSION "18.8"
+#define SND_VERSION "19.0"
 #endif
-#define SND_MAJOR_VERSION "18"
-#define SND_MINOR_VERSION "8"
+#define SND_MAJOR_VERSION "19"
+#define SND_MINOR_VERSION "0"
 
 #endif
