@@ -48,9 +48,9 @@
 	     (if (not (null? info))
 		 (format p ": ~A" info))))
 
-       (format p "~%error-code: ~S~%" (ow 'error-code))
+       (format p "~%error-code: ~S" (ow 'error-code))
        (when (ow 'error-line)
-	 (format p "~%error-file/line: ~S[~A]~%" (ow 'error-file) (ow 'error-line)))
+	 (format p "~%error-file/line: ~A[~A]" (ow 'error-file) (ow 'error-line)))
 	   
        ;; show history, if available
        (when (pair? (ow 'error-history)) ; a circular list, starts at error-code, entries stored backwards
@@ -109,12 +109,9 @@
      ,@(map (lambda (val)
 	      (if (pair? (cddr val))
 		  `(set! (setter ',(car val))
-			 (if (not (,(caddr val) ,(car val)))
+			 (if (not (,(caddr val) ,(car val))) ; check initial value (already set)
 			     (error 'wrong-type "initial value ~S is not ~S" ,(car val) ,(caddr val))
-			     (lambda (s v)
-			       (if (not (,(caddr val) v))
-				   (error 'wrong-type-arg "(set! ~S ~S) but ~S is not ~A" s v v ',(caddr val)))
-			       v)))
+			     ,(caddr val)))                  ; assume built-in type here
 		  (values)))
 	    vals)
      ,@body))
@@ -433,13 +430,7 @@
 	  (map values table)
 	  (error 'wrong-type-arg "hash-table->alist argument, ~A, is not a hash-table" table)))))
 
-(define merge-hash-tables 
-  (let ((+documentation+ "(merge-hash-tables . tables) returns a new hash-table with the contents of all the tables"))
-    (lambda tables
-      (apply hash-table 
-	     (apply append 
-		    (map hash-table->alist tables))))))
-
+(define merge-hash-tables append)
 
 
 ;;; ----------------
@@ -533,7 +524,9 @@ If func approves of one, index-if returns the index that gives that element's po
     (lambda (type f sequence)
       (unless (sequence? sequence)
 	(error 'wrong-type-arg "collect-if: sequence arg is ~A" sequence))
-      (apply type (map (lambda (arg) (if (f arg) arg (values))) sequence)))))
+      (if (eq? type hash-table)
+	  (apply hash-table (map (lambda (arg) (if (f arg) (values (car arg) (cdr arg)) (values))) sequence))
+	  (apply type (map (lambda (arg) (if (f arg) arg (values))) sequence))))))
 
 ;;; if type=list, this is slightly wasteful because list currently copies its args, so:
 ;;;   ((if (eq? type list) values (values apply type)) ...) would work
@@ -704,7 +697,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 ;;; ----------------
 (define sequences->list 
   (let ((+documentation+ "(sequences->list . sequences) returns a list of elements of all the sequences:\n\
-    (sequences->list \"hi\" #(0 1) (hash-table '(a . 2))) -> '(#\\h #\\i 0 1 (a . 2))"))
+    (sequences->list \"hi\" #(0 1) (hash-table 'a 2)) -> '(#\\h #\\i 0 1 (a . 2))"))
     (lambda sequences
       (apply append 
 	     (map (lambda (sequence) 
@@ -742,7 +735,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 				(if (not (member obj lst))
 				    (set! lst (cons obj lst))))
 			      (apply sequences->list sequences))
-		    (reverse lst))))))
+		    (if (eq? type hash-table)
+			(map (lambda (x) (values (car x) (cdr x))) (reverse lst))
+			(reverse lst)))))))
 
 (define asymmetric-difference 
   (let ((+documentation+ "(asymmetric-difference type . sequences) returns the elements in the rest of the sequences that are not in the first:\n\
@@ -1206,7 +1201,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			    (if (not (let? p))
 				(apply format p args)
 				(write (apply format #f args) p))))))
-    (subvector v (list i)))) ; ignore extra trailing elements
+    (subvector v i))) ; ignore extra trailing elements
 
 
 
@@ -1356,7 +1351,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	(error 'out-of-range "end: ~A should be greater than start: ~A" end start))
 
     (cond ((vector? obj) 
-	   (subvector obj (list new-len) start))
+	   (subvector obj new-len start))
 
           ((string? obj)
            (if (integer? end)
@@ -1386,7 +1381,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			((float-vector? val)  "#r(~{~A~| ~})")
 			((vector? val)        "#(~{~A~| ~})")
 			((let? val)           "(inlet ~{'~A~| ~})")
-			((hash-table? val)    "(hash-table ~{'~A~| ~})")
+			((hash-table? val)    "~W")
 			((not (string? val))  "(~{~A~| ~})")
 			(else                 "\"~{~A~|~}\""))))
     (format #f ctrl-str val)))
@@ -1464,7 +1459,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   (define (prepend-spaces)
     (format *display* (format #f "~~~DC" spaces) #\space))
   
-  (define (display-let le e)
+  (define (display-let le e) 
     (let ((vlp (*s7* 'print-length)))
       (for-each
        (lambda (slot)
@@ -1903,7 +1898,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	      list->vector vector-fill! vector-length vector->list vector-ref vector-set! vector-dimensions 
 	      make-vector subvector vector float-vector make-float-vector float-vector-set! 
 	      float-vector-ref int-vector make-int-vector int-vector-set! int-vector-ref string->byte-vector 
-	      byte-vector make-byte-vector hash-table hash-table* make-hash-table hash-table-ref 
+	      byte-vector make-byte-vector hash-table make-hash-table hash-table-ref weak-hash-table
 	      hash-table-set! hash-table-entries cyclic-sequences call/cc call-with-current-continuation 
 	      call-with-exit apply for-each map dynamic-wind values type-of
 	      catch throw error documentation signature help procedure-source
