@@ -7,7 +7,7 @@
 	(it-lst (make-list 3 #f)))
     (let ((bases (vector (make-list 3 #f)
 			 (make-vector 3 #f)
-			 (hash-table* 'a 1 'b 2 'c 3)
+			 (hash-table 'a 1 'b 2 'c 3)
 			 (inlet 'a 1 'b 2 'c 3)
 			 (make-iterator it-lst)
 			 (c-pointer 1 cp-lst)))
@@ -60,7 +60,7 @@
 (define mock-char (*mock-char* 'mock-char))
 (define mock-vector (*mock-vector* 'mock-vector))
 (define mock-symbol (*mock-symbol* 'mock-symbol))
-(define mock-hash-table* (*mock-hash-table* 'mock-hash-table*))
+(define mock-hash-table (*mock-hash-table* 'mock-hash-table))
 
 (set! (*s7* 'safety) 1)
 
@@ -177,7 +177,7 @@
   (and (null? (cyclic-sequences code))
        (eval code)))
 
-(define (checked-hash-table* . args)
+(define (checked-hash-table . args)
   (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) morally-equal?)))
     (do ((key/value args (cddr key/value)))
 	((null? key/value) _h_)
@@ -315,7 +315,7 @@
 (define imfv (immutable! (float-vector 0 1 2)))
 (define imi (immutable! (inlet 'a 1 'b 2)))
 (define imb (immutable! (block 0.0 1.0 2.0)))
-(define imh (immutable! (hash-table* 'a 1 'b 2)))
+(define imh (immutable! (hash-table 'a 1 'b 2)))
 ;(define imp (immutable! (cons 0 (immutable! (cons 1 (immutable! (cons 2 ())))))))
 
 (set! (hook-functions *unbound-variable-hook*) ())
@@ -363,7 +363,7 @@
 			  'continuation? 'hash-table? 'port-closed? 
 			  'output-port? 'input-port? 
 			  'provide 'call-with-output-string 
-			  'checked-hash-table 'checked-hash-table*
+			  'checked-hash-table 'checked-hash-table
 			  'with-output-to-string 
 			  ;'symbol-setter 
 			  's7-version 
@@ -404,7 +404,7 @@
                           ;'port-line-number ;-- too many spurious diffs
 			  ;'load  ;'current-error-port ;-- spurious output
 			  ;'close-output-port 
-			  ; 'hash-table 'hash-table*; -- handled as morally equal via checked-hash-table
+			  ; 'hash-table ; -- handled as morally equal via checked-hash-table
 			  ;'current-output-port 
 			  ;'cutlet 
 			  ;'set-current-error-port ;-- too many bogus eq? complaints
@@ -566,9 +566,9 @@
 		    ;;"(f x) i" "x y z" "1 2"
 		    "`(+ ,a ,@b)" "`(+ ,a ,b)" "`(+ ,a ,b ,@c)" "`(+ ,a b ,@c ',d)"
 		    "_definee_" "(_definee_ __var__)" "(_definee_ x)" 
-		    "(hash-table* 'a 1)" "(hash-table)" 
+		    "(hash-table 'a 1)" "(hash-table)" 
 		    "(make-iterator (list 11 22 33))" "(make-iterator (int-vector 1 2 3))" "(make-iterator (string #\\1))" "(make-iterator x)" 
-		    "(make-iterator (hash-table* 'a 1 'b 2))" "(make-iterator (block 1 2 3))"
+		    "(make-iterator (hash-table 'a 1 'b 2))" "(make-iterator (block 1 2 3))"
 		    "(make-iterator (let ((lst '((a . 1) (b . 2) (c . 2))) 
                                        (+iterator+ #t)) (lambda () (if (pair? lst) (let ((res (list (caar lst) (cdar lst)))) (set! lst (cdr lst)) res) #<eof>))))"
 
@@ -605,7 +605,7 @@
 		    "(mock-char #\\b)"
 		    "(mock-symbol 'c)"
 		    "(mock-vector 1 2 3 4)"
-		    "(mock-hash-table* 'b 2)"
+		    "(mock-hash-table 'b 2)"
 
 		    ;;" #| a comment |# "
 		    "(subvector (vector 0 1 2 3 4) 3)" "(substring \"0123\" 2)"
@@ -626,7 +626,7 @@
 
 		    "(let ((<1> (vector #f))) (set! (<1> 0) <1>) <1>)"
 		    "(let ((<1> (inlet :a #f))) (set! (<1> :a) <1>) <1>)"
-		    "(let ((<1> (hash-table*))) (set! (<1> 'a) <1>) <1>)"
+		    "(let ((<1> (hash-table))) (set! (<1> 'a) <1>) <1>)"
 		    "(let ((<1> #f) (<2> (vector #f))) (set! <1> (make-iterator <2>)) (set! (<2> 0) <1>) <1>)"
 		    "(let ((<1> (list 1 #f))) (set! (<1> 1) (let ((<L> (list #f 3))) (set-car! <L> <1>) <L>)) <1>)"
 
