@@ -2,7 +2,7 @@
 ;;; (dups size file alloc-lines): 
 ;;;    find all matches of "size" successive lines in "file" ignoring empty lines and leading/trailing whitespace
 ;;;    "alloc-lines" is any number bigger than the number of lines in "file"
-;;;    (dups 16 "s7.c" 89000) finds all 16-line matches in s7.c which has less than 89000 lines in all
+;;;    (dups 16 "s7.c" 91000) finds all 16-line matches in s7.c which has less than 91000 lines in all
 
 (set! (*s7* 'heap-size) (* 2 1024000))
 
@@ -13,9 +13,7 @@
       (do ((j (- end 1) (- j 1)))
 	  ((or (negative? (int-vector-ref v j))
 	       (= j start))
-	   (if (= j start)
-	       end
-	       j))))
+	   j)))
 
     (lambda (size file alloc-lines)
       (let ((lines (make-vector alloc-lines ""))
@@ -57,7 +55,7 @@
 			     (set! j (+ j 1)))))))))
 	      
 	      (set! size (min size total-lines))
-	      ;; (format *stderr* "lines: ~S~%" total-lines)
+	      ;; (format *stderr* "lines: ~S~%" total-lines)         ; 79881
 
 	      ;; mark unmatchable strings
 	      (let ((sortv (make-vector total-lines)))
@@ -66,42 +64,46 @@
 		  (vector-set! sortv i (cons (vector-ref lines i) i)))
 		(set! sortv (sort! sortv (lambda (a b)
 					   (string<? (car a) (car b)))))
-		(let ((unctr -1))
-		  (do ((i 0))
-		      ((= i total-lines))
-		    (let ((current (car (vector-ref sortv i))))
-		      (do ((k (+ i 1) (+ k 1)))
-			  ((or (= k total-lines)
-			       (not (string=? current (car (vector-ref sortv k)))))
-			   (when (= i (- k 1))
-			     (int-vector-set! lens (cdr (vector-ref sortv i)) unctr)
-			     (set! unctr (- unctr 1)))
-			   (set! i k)))))))
+		(let ((unctr -1)
+		      (matches #f)
+		      (current (vector-ref sortv 0)))
+		  (for-each (lambda (srt)
+			      (if (string=? (car current) (car srt))
+				  (set! matches #t)
+				  (begin
+				    (unless matches
+				      (int-vector-set! lens (cdr current) unctr)
+				      (set! unctr (- unctr 1)))
+				    (set! matches #f)
+				    (set! current srt))))
+			    sortv)
+		  ;; (format *stderr* "unmatched: ~D~%" (abs unctr)) ; 33796
+		  ))
 
 	      ;; look for matches
-	      (do ((i 0 (+ i 1))
-		   (first #t #t)
-		   (last-line (- total-lines size)))
+	      (do ((first #t #t)
+		   (last-line (- total-lines size))
+		   (i 0 (+ i 1)))
 		  ((>= i last-line)) ; >= because i is set below
 		(let ((j (all-positive? lens i (+ i size))))   ; is a match possible?
-		  (if (not (= j (+ i size)))
+		  (if (not (= j i))
 		      (set! i j)
 		      (let ((lenseq (subvector lens size i))
 			    (lineseq (subvector lines size i)))
 			(do ((k (+ i 1) (+ k 1)))
 			    ((>= k last-line))
 			  (let ((jk (all-positive? lens k (+ k size))))
-			    (if (not (= jk (+ k size)))
+			    (if (not (= jk k))
 				(set! k jk)
 				(when (and (equal? lenseq (subvector lens size k))
 					   (equal? lineseq (subvector lines size k)))
 				  (let ((full-size size))
-				    (do ((nk jk (+ nk 1))
-					 (ni j (+ ni 1)))
+				    (do ((nk (+ k size) (+ nk 1))
+					 (ni (+ i size) (+ ni 1)))
 					((or (= nk total-lines)
 					     (not (= (int-vector-ref lens ni) (int-vector-ref lens nk)))
 					     (not (string=? (vector-ref lines ni) (vector-ref lines nk))))
-					 (set! full-size (- (+ size nk) jk))))
+					 (set! full-size (- nk k))))
 				    (if first
 					(let ((first-line (int-vector-ref linenums i)))
 					  (format *stderr* "~NC~%~{~A~%~}~%  lines ~D ~D" 8 #\- ; lineseq 
@@ -117,6 +119,10 @@
 			  (format *stderr* "~%")))))))))))))
 
 (dups 16 "s7.c" 91000)
-;(dups 6 "s7.c" 91000)
+;(dups 2 "s7.c" 91000)
 ;(dups 12 "ffitest.c" 2000)
 ;(dups 8 "ffitest.c" 2000)
+;(dups 16 "s7test.scm" 100000)
+
+(s7-version)
+(exit)
