@@ -54,6 +54,35 @@
   ;;               "`(ok? ',tst (lambda () (let ((!x 0)) (let-temporarily ((!x ,tst)) !x))) ,expected)"
   ))
 
+#|
+;; this quits at the quoted circular list (car '#1= (2 . #1#))
+(set! (*s7* 'safety) 1)
+
+(define-macro (test tst expected)
+  (let ((_call_ (gensym))
+	(_caller_ (gensym)))
+    `(ok? ',tst 
+	  (lambda ()
+	    (define (,_caller_) (,_call_ ,tst))
+	    (define (,_call_ x) x)
+	    (,_caller_)
+	    (,_caller_))
+	  ,expected)))
+
+(define-macro (num-test tst expected)
+  (let ((_call_ (gensym))
+	(_caller_ (gensym)))
+    `(nok? ',tst 
+	  (lambda ()
+	    (define (,_caller_) (,_call_ ,tst))
+	    (define (,_call_ x) x)
+	    (,_caller_)
+	    (,_caller_))
+	  ,expected)))
+  
+(load "s7test.scm")
+|#
+
 (format *stderr* "~NC ffitest ~NC~%" 20 #\- 20 #\-)
 (if (provided? 'linux)
     (begin
@@ -91,13 +120,13 @@
 (system "./snd -e '(let () (catch #t (lambda () (load \"s7test.scm\" (curlet))) (lambda args #f)) (exit))'")
 
 (format *stderr* "~NC s7test ~NC~%" 20 #\- 20 #\-)
-(system "./snd s7test.scm")
+(system "./repl s7test.scm")
 
 (format *stderr* "~NC tpeak ~NC~%" 20 #\- 20 #\-)
-(system "./snd tpeak.scm")
+(system "./repl tpeak.scm")
 
 (format *stderr* "~NC lt ~NC~%" 20 #\- 20 #\-)
-(system "./snd lt.scm")
+(system "./repl lt.scm")
 
 (format *stderr* "~NC tcopy ~NC~%" 20 #\- 20 #\-)
 (system "./repl tcopy.scm")
@@ -126,14 +155,28 @@
 (format *stderr* "~NC tset ~NC~%" 20 #\- 20 #\-)
 (system "./repl tset.scm")
 
+(format *stderr* "~NC tref ~NC~%" 20 #\- 20 #\-)
+(system "./repl tref.scm")
+
+(format *stderr* "~NC tsort ~NC~%" 20 #\- 20 #\-)
+(system "./repl tsort.scm")
+
+(format *stderr* "~NC tclo ~NC~%" 20 #\- 20 #\-)
+(system "./repl tclo.scm")
+
+(format *stderr* "~NC tshoot ~NC~%" 20 #\- 20 #\-)
+(system "./repl tshoot.scm")
+
 (format *stderr* "~NC index ~NC~%" 20 #\- 20 #\-)
 (system "./snd make-index.scm")
 
+#|
 (format *stderr* "~NC makexg ~NC~%" 20 #\- 20 #\-)
 (system "./snd makexg.scm")
 
 (format *stderr* "~NC makegl ~NC~%" 20 #\- 20 #\-)
 (system "./snd makegl.scm")
+|#
 
 (format *stderr* "~NC tgen ~NC~%" 20 #\- 20 #\-)
 (system "./snd tgen.scm")
@@ -145,7 +188,7 @@
 (system "./snd -l snd-test.scm")
 
 (format *stderr* "~NC bench ~NC~%" 20 #\- 20 #\-)
-(system "(cd /home/bil/test/scheme/bench/src ; /home/bil/cl/snd test-all.scm)")
+(system "(cd /home/bil/test/scheme/bench/src ; /home/bil/cl/repl test-all.scm)")
 
 ;(format *stderr* "~NC lg ~NC~%" 20 #\- 20 #\-)
 ;(system "./repl lg.scm")
