@@ -20,7 +20,7 @@
 (define mock-char (*mock-char* 'mock-char))
 (define mock-vector (*mock-vector* 'mock-vector))
 (define mock-symbol (*mock-symbol* 'mock-symbol))
-(define mock-hash-table* (*mock-hash-table* 'mock-hash-table*))
+(define mock-hash-table (*mock-hash-table* 'mock-hash-table))
 
 (define np (list 0 1 2 3 4))
 (define mp (mock-pair '(0 1 2 3 4)))
@@ -66,7 +66,7 @@
 			(mock-char #\b)
 			(mock-symbol 'c)
 			(mock-vector 1 2 3 4)
-			(mock-hash-table* 'b 2)
+			(mock-hash-table 'b 2)
 			np mp nv mv ns ms (gensym)
 			))
       
@@ -141,18 +141,22 @@
 		    (for-each call-func1 cdr-auto-constants)
 		    (for-each call-func2 cdr-auto-constants))))
 
-	     (if checker
-		 (for-each
-		  (lambda (c)
-		    (when (checker c)
+	     (let ((sig1 (if (pair? sig) (cdr sig) ()))
+		   (c-args1 c-args)
+		   (args-now1 (+ args-now 1))
+		   (args-left1 (- args-left 1)))
+	       (if checker
+		   (for-each
+		    (lambda (c)
+		      (when (checker c)
+			(set-car! p c)
+			(autotest func c-args1 args-now1 args-left1 sig1)))
+		    auto-constants)
+		   (for-each
+		    (lambda (c)
 		      (set-car! p c)
-		      (autotest func c-args (+ args-now 1) (- args-left 1) (if (pair? sig) (cdr sig) ()))))
-		  auto-constants)
-		 (for-each
-		  (lambda (c)
-		    (set-car! p c)
-		    (autotest func c-args (+ args-now 1) (- args-left 1) (if (pair? sig) (cdr sig) ())))
-		  auto-constants))))))))
+		      (autotest func c-args1 args-now1 args-left1 sig1))
+		    auto-constants)))))))))
 
 (define safe-fill!
   (let ((+signature+ '(#t sequence? #t)))
@@ -175,11 +179,11 @@
 (define baddies '(exit emergency-exit abort autotest s7-optimize
 		  all delete-file system set-cdr! stacktrace test-sym
 		  cutlet varlet gc cond-expand reader-cond
-		  openlet coverlet eval vector list cons hash-table* hash-table values
-		  symbol-table load 
+		  openlet coverlet eval vector list cons values
+		  symbol-table load throw error
 		  global-environment current-environment make-rectangular
 		  copy fill! hash-table-set! vector-set! let-set! list-values apply-values immutable!
-		  mock-number mock-pair mock-string mock-char mock-vector mock-hash-table*
+		  mock-number mock-pair mock-string mock-char mock-vector mock-hash-table
 		  mock-symbol mock-port mock-hash-table m mock->string make-local-method
 		  *mock-number* *mock-pair* *mock-string* *mock-char* *mock-vector*
 		  *mock-symbol* *mock-port* *mock-hash-table* mp ms mv
