@@ -17,7 +17,7 @@
        (format *stderr* "    ~A~S -> ~S?~A~%" bold-text ',a ,a unbold-text)))
 
 (define (clear-and-gc)
-  (do ((x 0.0) (i 0 (+ i 1))) ((= i 256)) (set! x (complex i i))) ; clear temps
+  (let ((x 0+i)) (do ((i 0 (+ i 1))) ((= i 256)) (set! x (complex i i)))) ; clear temps
   (gc) (gc))
 
 (define total-memory (with-let *libc* (* (sysconf _SC_PHYS_PAGES) (sysconf _SC_PAGESIZE)))) ; not quite what we want, but...
@@ -89,9 +89,10 @@
       (format () "noise: ~A~%" mx))))
 
 (define (complex-test)
-  (let ((fvr (make-vector fft-size 0.0 complex?)))
+  (let ((fvr (make-vector fft-size 0.0 complex?))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (sin x)))
     (complex-fft fvr fft-size 1)
@@ -181,9 +182,10 @@
 
 (define (ratio-test)
   (let ((fvr (make-vector fft-size 0 rational?))
-	(fvi (make-vector fft-size 0 rational?)))
+	(fvi (make-vector fft-size 0 rational?))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (set! (fvr i) (rationalize (sin x))))
     (ratio-fft fvr fvi fft-size 1)
@@ -209,7 +211,7 @@
     (test (length bigstr) big-size)
     (string-set! bigstr (- big-size 10000000) #\a)
     (test (string-ref bigstr (- big-size 10000000)) #\a)
-    (reverse! bigstr)
+    (set! bigstr (reverse! bigstr))
     (test (string-ref bigstr (- 10000000 1)) #\a)
     (fill! bigstr #\b)
     (test (string-ref bigstr (- big-size 10000000)) #\b)
@@ -271,7 +273,8 @@
 	    ((= i size))
 	  (if (string>? (vector-ref vs j) (vector-ref vs i))
 	      (display "oops"))))
-      (string-checker)))
+      (string-checker)
+      (fill! vs #f)))
   
   (clear-and-gc)
   (let ((size little-size))
@@ -346,7 +349,7 @@
     (test (length bigstr) big-size)
     (byte-vector-set! bigstr (- big-size 10000000) 65)
     (test (byte-vector-ref bigstr (- big-size 10000000)) 65)
-    (reverse! bigstr)
+    (set! bigstr (reverse! bigstr))
     (test (byte-vector-ref bigstr (- 10000000 1)) 65)
     (fill! bigstr 66)
     (test (byte-vector-ref bigstr (- big-size 10000000)) 66))
@@ -361,11 +364,12 @@
       (byte-vector-sorter)
       (sort! vs <)
       (define (byte-vector-checker)
-	(do ((i 1 (+ i 1))
-	     (j 0 (+ j 1)))
-	    ((= i size))
-	  (if (> (byte-vector-ref vs j) (byte-vector-ref vs i))
-	      (display "oops"))))
+ 	(let ((vj (byte-vector-ref vs 0)))
+ 	  (for-each
+ 	   (lambda (vi)
+ 	     (if (> vj vi) (display "oops"))
+ 	     (set! vj vi))
+ 	   (subvector vs (- size 1) 1))))
       (byte-vector-checker)))
   
   (clear-and-gc)
@@ -399,7 +403,7 @@
 	(test (morally-equal? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 0.25)
 	(test (morally-equal? big1 bigfv) #f)
-	(let ((big2 (subvector big1 (list 20) (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
 	  (test big2 (make-float-vector 20 0.5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-float-vector 20 0.0)))
@@ -426,11 +430,12 @@
       (float-vector-sorter)
       (sort! vs <)
       (define (float-vector-checker)
-	(do ((i 1 (+ i 1))
-	     (j 0 (+ j 1)))
-	    ((= i size))
-	  (if (> (float-vector-ref vs j) (float-vector-ref vs i))
-	      (display "oops"))))
+ 	(let ((vj (float-vector-ref vs 0)))
+ 	  (for-each
+ 	   (lambda (vi)
+ 	     (if (> vj vi) (display "oops"))
+ 	     (set! vj vi))
+ 	   (subvector vs (- size 1) 1))))
       (float-vector-checker)))
   
   (clear-and-gc)
@@ -487,9 +492,9 @@
 	(set! (bigfv1 i) j)
 	(set! (bigfv2 i) (* (bigfv1 i) 2))))
     (f-loop)
-    (test (subvector bigfv1 (list 20) (- (ash 1 32) 10)) (float-vector 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
-    (test (subvector bigfv2 (list 20) (- (ash 1 32) 10)) (float-vector 0 2 4 6 8 10 12 14 16 18 20 22 24 26 28 30 32 34 36 38))
-    (test (subvector bigfv1 (list 5) (+ (ash 1 32) 5)) (float-vector 15 16 17 18 19))))
+    (test (subvector bigfv1 20 (- (ash 1 32) 10)) (float-vector 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
+    (test (subvector bigfv2 20 (- (ash 1 32) 10)) (float-vector 0 2 4 6 8 10 12 14 16 18 20 22 24 26 28 30 32 34 36 38))
+    (test (subvector bigfv1 5 (+ (ash 1 32) 5)) (float-vector 15 16 17 18 19))))
 
 (when (> total-memory (* 9 big-size))
   (format () "test 4~%")
@@ -602,9 +607,10 @@
 
 (define (float-vector-test)
   (let ((fvr (make-float-vector fft-size))
-	(fvi (make-float-vector fft-size 0.0)))
+	(fvi (make-float-vector fft-size 0.0))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (float-vector-set! fvr i (sin x)))
     (float-vector-fft fvr fvi fft-size 1)
@@ -706,9 +712,10 @@
 
 (define (float-2d-test skip)
   (format *stderr* "float-2d ~A~%" skip)
-  (let ((fvr (make-float-vector (list skip fft-size) 0.0)))
+  (let ((fvr (make-float-vector (list skip fft-size) 0.0))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (float-vector-set! fvr 0 i (sin x)))
     (float-2d-fft fvr fft-size 1)
@@ -741,7 +748,7 @@
 	(test (morally-equal? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 25)
 	(test (morally-equal? big1 bigfv) #f)
-	(let ((big2 (subvector big1 (list 20) (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 20 (- (ash 1 31) 10))))
 	  (test big2 (make-int-vector 20 5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-int-vector 20 0)))
@@ -766,11 +773,12 @@
       (int-vector-sorter)
       (sort! vs <)
       (define (int-vector-checker)
-	(do ((i 1 (+ i 1))
-	     (j 0 (+ j 1)))
-	    ((= i size))
-	  (if (> (int-vector-ref vs j) (int-vector-ref vs i))
-	      (display "oops"))))
+ 	(let ((vj (int-vector-ref vs 0)))
+ 	  (for-each
+ 	   (lambda (vi)
+ 	     (if (> vj vi) (display "oops"))
+ 	     (set! vj vi))
+ 	   (subvector vs (- size 1) 1))))
       (int-vector-checker)))
   (sort! '(1 2 3) <) ; clear temp3...
   (clear-and-gc)
@@ -918,11 +926,12 @@
 
 (define (int-vector-test)
   (let ((fvr (make-int-vector fft-size))
-	(fvi (make-int-vector fft-size 0)))
+	(fvi (make-int-vector fft-size 0))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
-      (int-vector-set! fvr i (round (* 1000 (sin x)))))
+      (int-vector-set! fvr i (round (* 1000.0 (sin x)))))
     (int-vector-fft fvr fvi fft-size 1)
     (int-vector-checker fvr fvi)
     (int-vector-fft #f #f fft-size 1)
@@ -1047,9 +1056,10 @@
 
 (define (vector-test)
   (let ((fvr (make-vector fft-size 0.0 real?))
-	(fvi (make-vector fft-size 0.0 real?)))
+	(fvi (make-vector fft-size 0.0 real?))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (sin x)))
     (vector-fft fvr fvi fft-size 1)
@@ -1150,9 +1160,10 @@
       (format () "noise: ~A~%" mx))))
 
 (define (vector-2d-test skip)
-  (let ((fvr (make-vector (list skip fft-size) 0.0 real?)))
+  (let ((fvr (make-vector (list skip fft-size) 0.0 real?))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr 0 i (sin x)))
     (vector-2d-fft fvr fft-size 1)
@@ -1163,7 +1174,6 @@
 (vector-2d-test 2)
 (clear-and-gc)
 
-
 ;; --------------------------------------------------------------------------------
 (format () "~%blocks...~%")
 
@@ -1206,10 +1216,10 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (* pi dir) (* theta 0.5)))
+	   (theta (* pi dir) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
@@ -1217,9 +1227,9 @@
 	      (wi 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tempr (- (* wr (rl j)) (* wi (im j))))
 		    (tempi (+ (* wr (im j)) (* wi (rl j)))))
@@ -1235,9 +1245,10 @@
 
 (define (block-test)
   (let ((fvr (make-block fft-size))
-	(fvi (make-block fft-size)))
+	(fvi (make-block fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (set! (fvr i) (sin x)))
     (block-fft fvr fvi fft-size 1)
@@ -1309,12 +1320,12 @@
 	  (set! end (+ ii (* pw mmax)))
 	  (do ((i ii (+ i mmax)))
 	      ((= i end))
-	    (set! tempr (- (* wr ((vector-ref rl j) 0)) (* wi ((vector-ref im j) 0))))
-	    (set! tempi (+ (* wr ((vector-ref im j) 0)) (* wi ((vector-ref rl j) 0))))
-	    (vector-set! rl j (block (- ((vector-ref rl i) 0) tempr)))
-	    (vector-set! rl i (block (+ ((vector-ref rl i) 0) tempr)))
-	    (vector-set! im j (block (- ((vector-ref im i) 0) tempi)))
-	    (vector-set! im i (block (+ ((vector-ref im i) 0) tempi)))
+	    (set! tempr (- (* wr (block-ref (vector-ref rl j) 0)) (* wi (block-ref (vector-ref im j) 0))))
+	    (set! tempi (+ (* wr (block-ref (vector-ref im j) 0)) (* wi (block-ref (vector-ref rl j) 0))))
+	    (vector-set! rl j (block (- (block-ref (vector-ref rl i) 0) tempr)))
+	    (vector-set! rl i (block (+ (block-ref (vector-ref rl i) 0) tempr)))
+	    (vector-set! im j (block (- (block-ref (vector-ref im i) 0) tempi)))
+	    (vector-set! im i (block (+ (block-ref (vector-ref im i) 0) tempi)))
 	    (set! j (+ j mmax)))
 	  (set! wtemp wr)
 	  (set! wr (- (* wr wpr) (* wi wpi)))
@@ -1334,8 +1345,8 @@
 	  (mxloc 0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
-	(set! vr ((vector-ref fvr i) 0))
-	(set! vi ((vector-ref fvi i) 0))
+	(set! vr (block-ref (vector-ref fvr i) 0))
+	(set! vi (block-ref (vector-ref fvi i) 0))
 	(set! pk (+ (* vr vr) (* vi vi)))
 	(when (> pk mx)
 	  (set! mx pk)
@@ -1349,14 +1360,15 @@
     (let ((mx 0.0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
-	(set! mx (max mx (abs ((vector-ref fvr i) 0)) (abs ((vector-ref fvi i) 0)))))
+	(set! mx (max mx (abs (block-ref (vector-ref fvr i) 0)) (abs (block-ref (vector-ref fvi i) 0)))))
       (format () "noise: ~A~%" mx))))
 
 (define (block-vector-test)
   (let ((fvr (make-vector fft-size))
-	(fvi (make-vector fft-size (block 0.0))))
+	(fvi (make-vector fft-size (block 0.0)))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (block (sin x))))
     (block-vector-fft fvr fvi fft-size 1)
@@ -1368,6 +1380,7 @@
 (clear-and-gc)
 
 
+
 ;; --------------------------------------------------------------------------------
 ;; hash-tables round up to the next power of 2
 
@@ -1385,8 +1398,7 @@
     (test (hash-table-ref bigv (- big-size 10000000)) 'asdf)
     (fill! bigv #f)
     (test (hash-table-entries bigv) 0)
-    (test (length bigv) 2147483648)
-    )
+    (test (length bigv) 2147483648))
   (clear-and-gc)
   )
 
@@ -1422,10 +1434,10 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (* pi dir) (* theta 0.5)))
+	   (theta (* pi dir) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
@@ -1433,9 +1445,9 @@
 	      (wi 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tempr (- (* wr (hash-table-ref rl j)) (* wi (hash-table-ref im j))))
 		    (tempi (+ (* wr (hash-table-ref im j)) (* wi (hash-table-ref rl j)))))
@@ -1451,9 +1463,10 @@
 
 (define (hash-test)
   (let ((fvr (make-hash-table fft-size))
-	(fvi (make-hash-table fft-size)))
+	(fvi (make-hash-table fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (hash-table-set! fvr i (sin x))
       (hash-table-set! fvi i 0.0))
@@ -1502,10 +1515,10 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (* pi dir) (* theta 0.5)))
+	   (theta (* pi dir) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
@@ -1513,9 +1526,9 @@
 	      (wi 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tempr (- (* wr (hash-table-ref rl (vector-ref rl-syms j))) (* wi (hash-table-ref im (vector-ref im-syms j)))))
 		    (tempi (+ (* wr (hash-table-ref im (vector-ref im-syms j))) (* wi (hash-table-ref rl (vector-ref rl-syms j))))))
@@ -1533,9 +1546,10 @@
   (let ((fvr (hash-table))
 	(fvi (hash-table))
 	(rl-syms (make-vector fft-size))
-	(im-syms (make-vector fft-size)))
+	(im-syms (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! rl-syms i (gensym "rl"))
       (vector-set! im-syms i (gensym "im"))
@@ -1594,10 +1608,10 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (* pi dir) (* theta 0.5)))
+	   (theta (* pi dir) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
@@ -1605,9 +1619,9 @@
 	      (wi 0.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tempr (- (* wr (let-ref rl (vector-ref rl-syms j))) (* wi (let-ref im (vector-ref im-syms j)))))
 		    (tempi (+ (* wr (let-ref im (vector-ref im-syms j))) (* wi (let-ref rl (vector-ref rl-syms j))))))
@@ -1625,9 +1639,10 @@
   (let ((fvr (inlet))
 	(fvi (inlet))
 	(rl-syms (make-vector fft-size))
-	(im-syms (make-vector fft-size)))
+	(im-syms (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! rl-syms i (gensym "rl-"))
       (vector-set! im-syms i (gensym "im-"))
@@ -1753,9 +1768,10 @@
 
 (define (string-test)
   (let ((fvr (make-vector fft-size))
-	(fvi (make-vector fft-size "0.0")))
+	(fvi (make-vector fft-size "0.0"))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (number->string (sin x))))
     (string-fft fvr fvi fft-size 1)
@@ -1860,9 +1876,10 @@
 
 (define (string-radix-test)
   (let ((fvr (make-vector fft-size))
-	(fvi (make-vector fft-size "0.0")))
+	(fvi (make-vector fft-size "0.0"))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (number->string (sin x) radix)))
     (string-radix-fft fvr fvi fft-size 1)
@@ -1965,9 +1982,10 @@
 
 (define (port-test)
   (let ((fvr (make-vector fft-size))
-	(fvi (make-vector fft-size "0.0")))
+	(fvi (make-vector fft-size "0.0"))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (number->string (sin x))))
     (port-fft fvr fvi fft-size 1)
@@ -1983,7 +2001,7 @@
   `(make-vector (make-list (+ 1 (random 4)) (+ 1 (random 4))) ,val))
 
 (define-expansion (old-value ref)
-  `((subvector ,ref '(1)) 0))
+  `((subvector ,ref 1) 0))
 
 (define (complex-2d-fft data n dir)
   (when data
@@ -2044,15 +2062,17 @@
       (format () "noise: ~A~%" mx))))
 
 (define (complex-2d-test)
-  (let ((fvr (make-vector fft-size)))
+  (let ((fvr (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (new-value (sin x))))
     (complex-2d-fft fvr fft-size 1)
     (complex-2d-checker fvr)
     (complex-2d-fft #f fft-size 1)
-    (complex-2d-checker #f)))
+    (complex-2d-checker #f)
+    (fill! fvr #f)))
 (complex-2d-test)
 
 (clear-and-gc)
@@ -2074,22 +2094,22 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (complex 0.0 (* pi dir)) (* theta 0.5)))
+	   (theta (complex 0.0 (* pi dir)) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpc (exp theta))
 	      (wc 1.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tc (* wc (hash-table-ref (vector-ref data j) 'z)))) ; this could be (data j 'z)!
-		(vector-set! data j (hash-table* 'z (- (hash-table-ref (vector-ref data i) 'z) tc)))
-		(vector-set! data i (hash-table* 'z (+ (hash-table-ref (vector-ref data i) 'z) tc)))))
+		(vector-set! data j (hash-table 'z (- (hash-table-ref (vector-ref data i) 'z) tc)))
+		(vector-set! data i (hash-table 'z (+ (hash-table-ref (vector-ref data i) 'z) tc)))))
 	    (set! wc (* wc wpc)))
 	  (set! prev mmax))))
     data))
@@ -2109,8 +2129,8 @@
       (format () "~A ~A~%" 
 	      (magnitude (hash-table-ref (vector-ref fvr 4) 'z))
 	      (magnitude (hash-table-ref (vector-ref fvr (- fft-size 4)) 'z))))
-    (vector-set! fvr 4 (hash-table* 'z 0.0))
-    (vector-set! fvr (- fft-size 4) (hash-table* 'z 0.0))
+    (vector-set! fvr 4 (hash-table 'z 0.0))
+    (vector-set! fvr (- fft-size 4) (hash-table 'z 0.0))
     (let ((mx 0.0))
       (do ((i 0 (+ i 1)))
 	  ((= i fft-size))
@@ -2118,15 +2138,17 @@
       (format () "noise: ~A~%" mx))))
 
 (define (complex-hash-test)
-  (let ((fvr (make-vector fft-size)))
+  (let ((fvr (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
-      (vector-set! fvr i (hash-table* 'z (sin x))))
+      (vector-set! fvr i (hash-table 'z (sin x))))
     (complex-hash-fft fvr fft-size 1)
     (complex-hash-checker fvr)
     (complex-hash-fft #f fft-size 1)
-    (complex-hash-checker #f)))
+    (complex-hash-checker #f)
+    (fill! fvr #f)))
 (complex-hash-test)
 
 (clear-and-gc)
@@ -2222,16 +2244,19 @@
 
 (define (iterator-vector-test)
   (let ((fvr (make-vector fft-size))
-	(fvi (make-vector fft-size)))
+	(fvi (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvi i (make-iterator (make-float-vector 2 0.0)))
       (vector-set! fvr i (make-iterator (make-float-vector 2 (sin x)))))
     (iterator-vector-fft fvr fvi fft-size 1)
     (iterator-vector-checker fvr fvi)
     (iterator-vector-fft #f #f fft-size 1)
-    (iterator-vector-checker #f #f)))
+    (iterator-vector-checker #f #f)
+    (fill! fvr #f)
+    (fill! fvi #f)))
 
 (iterator-vector-test)
 (clear-and-gc)
@@ -2253,18 +2278,18 @@
 	(set! j (+ j m))))
     (let ((ipow (floor (log n 2)))
 	  (prev 1))
-      (do ((lg 0 (+ lg 1))
-	   (mmax 2 (* mmax 2))
+      (do ((mmax 2 (* mmax 2))
 	   (pow (/ n 2) (/ pow 2))
-	   (theta (complex 0.0 (* pi dir)) (* theta 0.5)))
+	   (theta (complex 0.0 (* pi dir)) (* theta 0.5))
+	   (lg 0 (+ lg 1)))
 	  ((= lg ipow))
 	(let ((wpc (exp theta))
 	      (wc 1.0))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
-	    (do ((jj 0 (+ jj 1))
-		 (i ii (+ i mmax))
-		 (j (+ ii prev) (+ j mmax)))
+	    (do ((i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax))
+		 (jj 0 (+ jj 1)))
 		((>= jj pow))
 	      (let ((tc (* wc ((vector-ref data j))))) 
 		(vector-set! data j (let ((z (- ((vector-ref data i)) tc))) (lambda () z)))
@@ -2297,18 +2322,20 @@
       (format () "noise: ~A~%" mx))))
 
 (define (complex-closure-test)
-  (let ((fvr (make-vector fft-size)))
+  (let ((fvr (make-vector fft-size))
+	(scl (/ (* 8.0 pi) fft-size)))
     (do ((i 0 (+ i 1))
-	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	 (x 0.0 (+ x scl)))
 	((= i fft-size))
       (vector-set! fvr i (let ((z (sin x))) (lambda () z))))
     (complex-closure-fft fvr fft-size 1)
     (complex-closure-checker fvr)
     (complex-closure-fft #f fft-size 1)
-    (complex-closure-checker #f)))
+    (complex-closure-checker #f)
+    (fill! fvr #f)))
 (complex-closure-test)
 
-(clear-and-gc)
+;(clear-and-gc)
 
 
 (s7-version)
