@@ -11,7 +11,7 @@
 (define mock-char (*mock-char* 'mock-char))
 (define mock-vector (*mock-vector* 'mock-vector))
 (define mock-symbol (*mock-symbol* 'mock-symbol))
-(define mock-hash-table* (*mock-hash-table* 'mock-hash-table*))
+(define mock-hash-table (*mock-hash-table* 'mock-hash-table))
 
 (define np (list 0 1 2 3 4))
 (define mp (mock-pair '(0 1 2 3 4)))
@@ -45,7 +45,7 @@
 			  (byte-vector 0 1 2) (byte-vector) (byte-vector 255 0 127) (make-iterator (vector '(a . 2)))
 			  (lambda (dir) 1.0) (float-vector) (make-float-vector '(2 2)) (int-vector 1 2 3) (int-vector)
 			  (inlet 'value 1 '+ (lambda args 1)) (inlet) (make-iterator (inlet 'a 1 'b 2) (cons #f #f))
-			  (make-iterator "123456") (make-iterator '(1 2 3)) (make-iterator (hash-table* 'a 1 'b 2) (cons #f #f))
+			  (make-iterator "123456") (make-iterator '(1 2 3)) (make-iterator (hash-table 'a 1 'b 2) (cons #f #f))
 			  (open-input-string "123123") (open-input-file "/home/bil/cl/4.aiff")
 			  (open-output-file "test.test") (open-output-string)
 			  
@@ -55,7 +55,7 @@
 			  (mock-char #\b)
 			  (mock-symbol 'c)
 			  (mock-vector 1 2 3 4)
-			  (mock-hash-table* 'b 2)
+			  (mock-hash-table 'b 2)
 			  
 			  (make-block 4) (block) (make-iterator (block 1 2 3 4))
 			  ))
@@ -79,6 +79,8 @@
 	 (size1 3 (+ size1 1))
 	 (tries 4000 (+ tries 2000))
 	 (pos 0)
+	 (cs constants)
+	 (cs-len constants-len)
 	 (ctrl-str (make-string 16 #\space)))
 	((= size 15))
       (format *stderr* "~D " size)
@@ -90,9 +92,9 @@
 	    ((= j size1))
 	  (string-set! ctrl-str j (string-ref ctrl-chars (random ctrl-chars-len))))
 	
-	(set! x (constants (random constants-len)))
-	(set! y (constants (random constants-len)))
-	(set! z (constants (random constants-len)))
+	(set! x (cs (random cs-len)))
+	(set! y (cs (random cs-len)))
+	(set! z (cs (random cs-len)))
 	
 	(object->string x)
 	(display x op)
@@ -114,10 +116,9 @@
       (get-output-string op #t))
     (close-output-port op)))
 
-;(do ((k 0 (+ k 1))) ((= k 1000)) (test-chars))
-
 (test-chars)
 
+;(do ((i 0 (+ i 1))) ((= i 1000)) (test-chars))
 
 (s7-version)
 (exit)
