@@ -36,7 +36,6 @@
 	    ((= i len))
 	  (if (> (fv (- i 1)) (fv i))
 	      (display "oops")))
-	      ;(format *stderr* "float-vector: ~A > ~A at ~D~%" (float-vector-ref fv (- i 1)) (float-vector-ref fv i) i)))
 	(sort! fv-ran (lambda (a b) (< a b)))
 	(if (not (morally-equal? fv fv-ran))
 	    (format *stderr* "float-vector closure not equal~%"))
@@ -199,13 +198,14 @@
 	(set! fv (sort! fv <))
 	(call-with-exit
 	 (lambda (quit)
-	   (do ((p0 fv (cdr p0))
-		(p1 (cdr fv) (cdr p1))
-		(i 1 (+ i 1)))
-	       ((null? p1))
-	     (when (> (car p0) (car p1))
-	       (format *stderr* "list: ~A > ~A at ~D~%" (car p0) (car p1) i)
-	       (quit)))))
+	   (let ((p0 (car fv)))
+	     (for-each
+	      (lambda (p1)
+		(when (> p0 p1)
+		  (format *stderr* "list: ~A > ~A~%" (car p0) (car p1))
+		  (quit))
+		(set! p0 p1))
+	      (cdr fv)))))
 	(set! fv-ran (sort! fv-ran (lambda (a b) (< a b))))
 	(if (not (equal? fv fv-ran))
 	    (format *stderr* "pair closure not equal~%")))
