@@ -1,6 +1,7 @@
 (define file-names '(("make-index.scm" . "v-index")
 		     ("tmac.scm" . "v-mac")
 		     ("tpeak.scm" . "v-peak")
+		     ("tvect.scm" . "v-vect")
 		     ("teq.scm" . "v-eq")
 		     ("tfft.scm" . "v-fft")
 		     ("tref.scm" . "v-ref")
@@ -11,7 +12,7 @@
 		     ("tform.scm" . "v-form")
 		     ("tread.scm" . "v-read")
 		     ("tmap.scm" . "v-map")
-		     ;("lg.scm" . "v-lg")
+		     ("lg.scm" . "v-lg")
 		     ("titer.scm" . "v-iter")
 		     ("tsort.scm" . "v-sort")
 		     ("tlet.scm" . "v-let")
@@ -19,10 +20,13 @@
 		     ("tgen.scm" . "v-gen")
 		     ("tall.scm" . "v-all")
 		     ("snd-test.scm" . "v-call")
+		     ("full-snd-test.scm" . "v-sg")
 		     ("dup.scm" . "v-dup")
 		     ("tset.scm" . "v-set")
 		     ("trec.scm" . "v-rec")
 		     ("tclo.scm" . "v-clo")
+		     ("tbig.scm" . "v-big")
+		     ("tshoot.scm" . "v-shoot")
 		     ))
 
 (define (last-callg)
@@ -62,6 +66,7 @@
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
    (list (list "repl" "tpeak.scm")
 	 (list "repl" "tmac.scm")
+	 (list "repl" "tshoot.scm")
 	 (list "repl" "tref.scm")
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tauto.scm")
@@ -72,19 +77,22 @@
 	 (list "repl" "tread.scm")
 	 (list "repl" "tform.scm")
 	 (list "repl" "tfft.scm")
-	 (list "repl" "tmap.scm")
+	 (list "repl" "tvect.scm")
 	 (list "repl" "tlet.scm")
-	 (list "repl" "titer.scm")
-	 (list "repl" "tsort.scm")
+	 (list "repl" "tmap.scm")
 	 (list "repl" "tclo.scm")
-	 ;(list "repl" "lg.scm")
-	 (list "repl" "thash.scm")
+	 (list "repl" "tsort.scm")
+	 (list "repl" "titer.scm")
 	 (list "repl" "dup.scm")
+	 (list "repl" "thash.scm")
 	 (list "repl" "tset.scm")
-	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "repl" "trec.scm")
+	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
+	 (list "snd -l" "full-snd-test.scm")
+	 (list "repl" "lg.scm")
+	 (list "repl" "tbig.scm")
 	 )))
 	 
 
